@@ -8,6 +8,7 @@ ProfileChangerWidget::ProfileChangerWidget (QWidget *parent) :
 QMainWindow(parent, Qt::FramelessWindowHint),
     ui(new Ui::ProfileChangerWidget)
 {
+    this->usageCounter = 0;
     ui->setupUi(this);
     QPalette palette;
     setAttribute(Qt::WA_TranslucentBackground);
@@ -26,6 +27,8 @@ QMainWindow(parent, Qt::FramelessWindowHint),
         settings.setValue(PCW_SETTING_SHOWNEXTPROFILE, PCW_SETTING_SHOWNEXTPROFILE_DEFAULT);
     if (!settings.contains(PCW_SETTING_LASTVERSION))
         settings.setValue(PCW_SETTING_LASTVERSION, PCW_SETTING_LASTVERSION_DEFAULT);
+    if (!settings.contains(PCW_SETTING_DEBUG))
+        settings.setValue(PCW_SETTING_DEBUG, PCW_SETTING_DEBUG_DEFAULT);
 
     connect(ui->switchButton, SIGNAL(clicked()), this, SLOT(onChangeProfileClicked()));
     this->reloadSettings();
@@ -103,6 +106,17 @@ void ProfileChangerWidget::switchProfile() {
 }  
 
 void ProfileChangerWidget::onChangeProfileClicked() {
+    this->usageCounter++;
+    if(this->usageCounter > PCW_APP_USAGE_LIMIT) {
+        this->usageCounter = 0;
+        if(PCW_APP_DEVEL) {
+            QString tmpInfo;
+            tmpInfo.append(tr("You installed a Profile Changer Widget from Extras-devel repository."));
+            tmpInfo.append("\n");
+            tmpInfo.append(tr("Don't play with Extras-devel if you haven't backed up your data or aren't prepared to re-flash your device."));
+            this->showQuestion(tmpInfo);
+        }
+    }
     switchProfile();
     refreshIcon();
 }
@@ -140,3 +154,21 @@ void ProfileChangerWidget::reloadSettings()
     this->refreshIcon();
 }
 
+void ProfileChangerWidget::showQuestion(QString info)
+{
+    QDBusMessage msg = QDBusMessage::createMethodCall(
+        "org.freedesktop.Notifications", // --dest
+        "/org/freedesktop/Notifications", // destination object path
+        "org.freedesktop.Notifications", // message name (w/o method)
+        "SystemNoteDialog" // method
+    );
+    QList<QVariant> args;
+    args.append(info);
+    args.append(static_cast<quint32>(0));
+    args.append("ok");
+
+    msg.setArguments(args);
+    msg = QDBusConnection::sessionBus().call(msg);
+
+}
+
