@@ -9,6 +9,16 @@
         <source>ProfileChangerWidget</source>
         <translation>Profilwechsel Widget</translation>
     </message>
+    <message>
+        <location filename="profilechangerwidget.cpp" line="114"/>
+        <source>You installed a Profile Changer Widget from Extras-devel repository.</source>
+        <translation>Sie haben das Profilwechsel Widget aus dem Extras-devel Repository installiert.</translation>
+    </message>
+    <message>
+        <location filename="profilechangerwidget.cpp" line="116"/>
+        <source>Don&apos;t play with Extras-devel if you haven&apos;t backed up your data or aren&apos;t prepared to re-flash your device.</source>
+        <translation>Experimentieren Sie nicht mit Extras-devel, wenn Sie Ihre Daten nicht gesichert haben und nicht bereit sind Ihr Gerät neu aufzusetzen.</translation>
+    </message>
 </context>
 <context>
     <name>SettingsDialog</name>
@@ -90,7 +100,7 @@
     <message>
         <location filename="settingsdialog.cpp" line="80"/>
         <source>Thank you for updating profile changer widget from version %1 to %2.</source>
-        <translation type="unfinished">Vielen Dank, dass Sie das Profilwechsel Widget von Version %1 auf %2 aktualisiert haben.</translation>
+        <translation>Vielen Dank, dass Sie das Profilwechsel Widget von Version %1 auf %2 aktualisiert haben.</translation>
     </message>
     <message>
         <location filename="settingsdialog.cpp" line="83"/>
@@ -105,7 +115,7 @@
     <message>
         <location filename="settingsdialog.cpp" line="106"/>
         <source>Not yet implemented.</source>
-        <translation type="unfinished">Noch nicht implementiert.</translation>
+        <translation>Noch nicht implementiert.</translation>
     </message>
 </context>
 </TS>
