@@ -16,7 +16,11 @@
 #define PCW_SETTING_SHOWNEXTPROFILE_DEFAULT true
 #define PCW_SETTING_LASTVERSION "profilechangerwidget/lastVersion"
 #define PCW_SETTING_LASTVERSION_DEFAULT "0.0"
-#define PCW_APP_VERSION "1.0"
+#define PCW_SETTING_DEBUG "profilechangerwidget/debug"
+#define PCW_SETTING_DEBUG_DEFAULT false
+#define PCW_APP_USAGE_LIMIT 10
+#define PCW_APP_DEVEL true
+#define PCW_APP_VERSION "1.0.1"
 
 namespace Ui {
     class SettingsDialog;
